build_context

Function build_context 

pub(super) fn build_context(
    config: &Config,
    verbosity: u8,
) -> Result<CommandContext>
Build the command context that will be used for the rest of the process.

The returned CommandContext combines application runtime state with UI preferences from the loaded config. The verbosity value only affects the runtime application context; it does not rewrite the persisted config.