load

Function load 

pub(super) fn load() -> Result<Config>
Load the current persisted configuration snapshot used by CLI startup.

This reads the active storage-backed configuration, including any path overrides that are already part of the environment-controlled config model.